/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.cache.eviction;

import org.jboss.cache.config.ConfigurationException;
import org.jboss.cache.config.parsing.XmlConfigHelper;
import org.jboss.cache.config.parsing.element.EvictionElementParser;
import static org.testng.AssertJUnit.*;
import org.testng.annotations.Test;
import org.w3c.dom.Element;

/**
 * Unit test for FIFOConfiguration.
 *
 * @author Daniel Huang (dhuang@jboss.org)
 * @version $Revision: 6574 $
 */
@Test(groups = "unit", sequential = false)
public class FIFOConfigurationTest
{
   public void testXMLParse() throws Exception
   {
      FIFOAlgorithmConfig config = new FIFOAlgorithmConfig();
      String xml = "<region name=\"abc\">" +
            "<attribute name=\"maxNodes\">1000</attribute>" +
            "</region>";

      Element element = XmlConfigHelper.stringToElementInCoreNS(xml);

      EvictionElementParser.parseEvictionPolicyConfig(element, config);
      config.validate();

      assertEquals(1000, config.getMaxNodes());

   }

   public void testXMLParse2() throws Exception
   {
      FIFOAlgorithmConfig config = new FIFOAlgorithmConfig();
      String xml = "<region name=\"abc\">" +
            "</region>";

      Element element = XmlConfigHelper.stringToElementInCoreNS(xml);

      try
      {
         EvictionElementParser.parseEvictionPolicyConfig(element, config);
         config.validate();
      }
      catch (ConfigurationException ce)
      {
         assertTrue("Configure Exception properly thrown", true);
         return;
      }
      fail("Invalid region FIFO configuration did not cause ConfigureException to be thrown");
   }

   public void testXMLParse3() throws Exception
   {
      FIFOAlgorithmConfig config = new FIFOAlgorithmConfig();
      String xml = "<region>" +
            "<attribute name=\"maxNodes\">1000</attribute>" +
            "</region>";

      Element element = XmlConfigHelper.stringToElementInCoreNS(xml);

      try
      {
         EvictionElementParser.parseEvictionPolicyConfig(element, config);
         config.validate();
      }
      catch (ConfigurationException ce)
      {
         assertTrue("Configure Exception properly thrown", true);
      }
   }
}
