/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.cache.eviction;

import org.jboss.cache.config.ConfigurationException;
import org.jboss.cache.config.parsing.XmlConfigHelper;
import org.jboss.cache.config.parsing.element.EvictionElementParser;
import static org.testng.AssertJUnit.assertEquals;
import static org.testng.AssertJUnit.assertTrue;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;
import org.w3c.dom.Element;

/**
 * Unit tests for MRUConfiguration.
 *
 * @author Daniel Huang (dhuang@jboss.org)
 * @version $Revision: 6574 $
 */
@Test(groups = "unit", sequential = false)
public class MRUConfigurationTest
{
   MRUAlgorithmConfig config = null;

   @BeforeMethod(alwaysRun = true)
   public void setUp() throws Exception
   {
      config = new MRUAlgorithmConfig();
   }

   public void testXMLParsing() throws Exception
   {
      String xml =
            "<region name=\"/org/jboss/data\">\n" +
                  "<attribute name=\"maxNodes\">5000</attribute>\n" +
                  "</region>";
      Element element = XmlConfigHelper.stringToElementInCoreNS(xml);

      EvictionElementParser.parseEvictionPolicyConfig(element, config);
      config.validate();

      assertEquals(5000, config.getMaxNodes());
   }

   public void testXMLParsing2() throws Exception
   {
      String xml = "<region name=\"/Test/\">\n" +
            "<attribute name=\"maxNodes\">10000</attribute>\n" +
            "</region>";
      Element element = XmlConfigHelper.stringToElementInCoreNS(xml);

      EvictionElementParser.parseEvictionPolicyConfig(element, config);
      config.validate();

      assertEquals(10000, config.getMaxNodes());
   }

   public void testXMLParsing3() throws Exception
   {
      String xml = "<region name=\"/Test/\">\n" +
            "</region>";
      Element element = XmlConfigHelper.stringToElementInCoreNS(xml);
      boolean caught = false;
      try
      {
         EvictionElementParser.parseEvictionPolicyConfig(element, config);
         config.validate();
      }
      catch (ConfigurationException ce)
      {
         caught = true;
      }
      assertTrue("Configure exception should have been caught, maxNodes is required", caught);

      xml = "<region name=\"/Test/\">\n" +
            "<attribute name=\"maxNodes\">10000</attribute>\n" +
            "</region>";

      element = XmlConfigHelper.stringToElementInCoreNS(xml);

      EvictionElementParser.parseEvictionPolicyConfig(element, config);
      config.validate();

      assertEquals(10000, config.getMaxNodes());
   }

}
