/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.cache.loader;

import org.testng.annotations.Test;
import org.testng.annotations.AfterMethod;
import org.jboss.cache.Cache;
import org.jboss.cache.DefaultCacheFactory;
import org.jboss.cache.CacheSPI;
import org.jboss.cache.Fqn;

/**
 * UT for testing JDBCCacheLoader during state transfer.
 * @author Mircea.Markus@jboss.com
 * @since 3.0
 */
@Test(groups = "functional")
public class JDBCCacheLoaderStateTransferTest
{

   CacheSPI first;
   CacheSPI second;

   @AfterMethod
   public void tearDown()
   {
      if (first != null) first.stop();
      if (second != null) second.stop();
   }

   public void testSimpleStateTransfer() throws Exception
   {
      first = (CacheSPI) new DefaultCacheFactory().createCache("configs/repl-with-cl.xml");
      first.put("/a/b/c", "key", "value");
      first.put("/a/b/d", "key", "value");
      first.put("/a/b/e", "key", "value");

      second = (CacheSPI) new DefaultCacheFactory().createCache("configs/repl-with-cl2.xml");
      assert second.get("/a/b/c","key").equals("value");
      assert second.get("/a/b/d","key").equals("value");
      assert second.get("/a/b/e","key").equals("value");
      JDBCCacheLoader cacheLoader = (JDBCCacheLoader) second.getCacheLoaderManager().getCacheLoader();
      assert cacheLoader.exists(Fqn.fromString("/a"));
      assert cacheLoader.exists(Fqn.fromString("/a/b"));
   }


   public void testMoreState()
   {
      long startTime = System.currentTimeMillis();
      first = (CacheSPI) new DefaultCacheFactory().createCache("configs/repl-with-cl.xml");
      long cacheStartTime = System.currentTimeMillis() - startTime;
      System.out.println("cacheStartTime = " + cacheStartTime);
      for (int i = 0; i < 5012; i++)
      {
         first.put("a/b/"+i, "k","v");
         if (i%1000 == 0) System.out.println(i + " operations executed so far");
      }
      startTime = System.currentTimeMillis();
      second = (CacheSPI) new DefaultCacheFactory().createCache("configs/repl-with-cl2.xml");

      long stateTranferTime = System.currentTimeMillis() - startTime - cacheStartTime;
      for (int i = 0; i < 5012; i+=100)
      {
         second.get("a/b/"+ i, "k").equals("v");
      }
      System.out.println("stateTranferTime = " + stateTranferTime);
   }
}
